UseSite

Struct UseSite 

pub struct UseSite {
    pub block: usize,
    pub instruction: usize,
    pub is_phi_operand: bool,
}
Use site of an SSA variable.

Records where in the program a variable is used (read).

Fields

block: usize

The block where this variable is used.

instruction: usize

The instruction index within the block.

For phi node operands, this refers to the phi node’s index in the block’s phi node list (not the instruction list).

is_phi_operand: bool

Whether this use is in a phi node operand.

Implementations

Source

impl UseSite

pub const fn instruction(block: usize, instr_idx: usize) -> Self

Creates a use site for a regular instruction.

pub const fn phi_operand(block: usize, phi_idx: usize) -> Self

Creates a use site for a phi node operand.